@@ -475,7 +475,7 @@ def picking_details(request_id):
 
     response = {
         "status": status,
-        "data": data
+        "details": data
         }
 
     return jsonify(response)
